<h1><img src="https://docs.basedpyright.com/latest/img/readme_logo.png"> basedpyright</h1>

basedpyright is a pyright fork with various type checking improvements, improved vscode support and pylance features built into the language server.

**[full documentation](https://docs.basedpyright.com)**

## ⚠ warning

this npm package is only really intended for internal use. the recommended way to install basedpyright is [from pypi](https://pypi.org/project/basedpyright/). see [the docs for more information](https://docs.basedpyright.com/latest/benefits-over-pyright/pypi-package-vscode-pinning/).

if you have a use case for the npm package, feel free to [raise an issue](https://github.com/DetachHead/basedpyright/issues).
